import { Component, OnInit } from '@angular/core';
import {FormBuilder, FormGroup} from '@angular/forms';
import {ADMIN_INFO_OBJECT} from '../../../../services/local-storage.namespace';
import {LocalStorageService} from '../../../../services/local-storage.service';
import {CompanyService} from '../../../../services/company.service';
import {CommonsService} from '../../../../services/commons.service';
import {animate, state, style, transition, trigger} from '@angular/animations';
import {NzMessageService} from 'ng-zorro-antd';
import {OrderThirdPartyService} from '../../../../services/order/order-third-party.service';
import {environment} from '../../../../../environments/environment';


@Component({
  selector: 'app-kfc-order-list',
    animations: [
        trigger('openClose', [
            state('open', style({
                height: '260px',
                opacity: 1,
                backgroundColor: 'white'
            })),
            state('closed', style({
                opacity: 1,
                backgroundColor: 'white'
            })),
            transition('open => closed', [
                animate('0.3s')
            ]),
            transition('closed => open', [
                animate('0.3s')
            ]),
        ]),
    ],
  templateUrl: './kfc-order-list.component.html',
  styleUrls: ['./kfc-order-list.component.scss']
})
export class KfcOrderListComponent implements OnInit {

    // 搜索框
    searchForm: FormGroup;
    // 搜索框折叠
    isCollapse = false;
    // 订单状态数据
    orderStatusArray = [];
    // 公司数据
    companyArray = [];
    // 角色类型
    roleType: number;
    // 列表相关参数
    // 总条数
    total: number;
    // 页码
    pageNum = 1;
    // 条码
    pageSize = 10;
    // 列表数据
    requestData = [];
    // 列表加载
    loading = true;
    // 订单详情相关参数
    // 详情模态框
    orderDetailModal = false;
    // 详情模态框数据等待
    orderDetailModalLoading = false;
    // 订单详情数据
    orderDetailObject: any = {
        tradeOrder: {},
    };
    // 数据加载中参数
    loadingObject = {
        title: '加载中...',
        status: false,
    };
    // 请求地址参数
    FILE_URL = environment.imageUrl;
  constructor(
      private form: FormBuilder,
      private store: LocalStorageService,
      private message: NzMessageService,
      private thirdPartyOrder: OrderThirdPartyService,
      private companyService: CompanyService,
      private commonsService: CommonsService,
  ) { }

  ngOnInit(): void {
      // 搜索表单初始化
      this.searchForm = this.form.group({
          orderNo: [null],
          memPhone: [null],
          payTimeArray: [null],
          orderStatus: [null],
          createTimeArray: [null],
          refundTimeArray: [null],
          companyId: [null],
          payType: [null],
          memCardNo: [null],
          productType: [2],
      });
      // 角色类型初始化
      this.roleType = Number(this.store.get(ADMIN_INFO_OBJECT)['secRole'].roleType);
      // 查询公司列表
      if (this.roleType === 0 || this.roleType === 1) {
          this.companyService.selectCompanyList({ pageNum: 1, pageSize: 999 }, data => {
              this.companyArray = data['return_data']['list'];
          });
      }
      // 查询订单状态数据
      this.commonsService.getDictionary('ORDER_OIL_STATUS', data => {
          this.orderStatusArray = data['return_data'];
      });
      this.getRequest(true, this.searchForm.value);
  }

    // 查询列表
    public getRequest(reset: boolean = false, whereObject: object) {
        this.loading = true;
        if (reset) {
            this.pageNum = 1;
        }
        whereObject['pageNum'] = this.pageNum;
        whereObject['pageSize'] = this.pageSize;
        this.thirdPartyOrder.getOrderList(whereObject, data => {
            this.loading = false;
            if (data['return_code'] === '000000') {
                console.log(data);
                this.requestData = data['return_data'].list;
                this.total = data['return_data'].total;
            } else {
                this.message.error(data['return_msg']);
            }
        });
    }

    // 展示订单详情
    public showOrderDetail(orderNo: string) {
        this.orderDetailModal = true;
        this.orderDetailModalLoading = true;
        this.thirdPartyOrder.getOrderDetail(orderNo, data => {
            if (data['return_code'] === '000000') {
                this.orderDetailObject = data['return_data'];
            } else {
                this.message.error(data['return_msg']);
            }
            this.orderDetailModalLoading = false;
        });

    }

    // 导出数据
    public excelOrder(whereObject) {
        this.loadingObject.status = true;
        this.loadingObject.title = '数据导出中...';
        this.thirdPartyOrder.exportThirdPartyOrderList(whereObject, data => {
            if (data['return_code'] === '000000') {
                window.location.href = this.FILE_URL + 'temporary/' + data['return_data'];
            } else {
                this.message.error(data['return_msg']);
            }
            this.loadingObject.status = false;
        });
    }

}


