import { Injectable } from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {CommonsService} from '../commons.service';
import {environment} from '../../../environments/environment';

@Injectable({
  providedIn: 'root'
})
export class OrderManageService {

  constructor(
      private http: HttpClient,
      private common: CommonsService
  ) {
  }

  /**
   * 查询交易订单
   *
   * @param  paramsObject   参数
   * @param  callBack   回调
   */
  public getDetailByOrderNo(orderNo: string, callBack) {
    this.http.get(environment.orderUrl + 'getDetailByOrderNo?orderNo='+ orderNo).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 交易订单退款
   *
   * @param  paramsObject   参数
   * @param  callBack   回调
   */
  public refundOrder(orderNo: string, remarks: string, callBack) {
    this.http.post(environment.orderUrl + 'refund', { orderNo: orderNo, remarks: remarks}).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 子订单商品退款
   *
   * @param  paramsObject   参数
   * @param  callBack   回调
   */
  public refundChild(childOrderNo: string, refundGoodsNum: number, remarks: string, callBack) {
    this.http.post(environment.orderUrl + 'refundChild', { orderNo: childOrderNo, refundGoodsNum: refundGoodsNum, remarks: remarks}).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 退款列表
   *
   * @param  paramsObject   参数
   * @param  callBack   回调
   */
  public getRefundList(param: object, callBack) {
    this.http.get(environment.orderUrl + 'getRefundList?'+this.common.getWhereCondition(param)).subscribe(data => {
      callBack(data);
    });
  }

  /**
   * 导出退款
   *
   * @param  paramsObject   参数
   * @param  callBack   回调
   */
  public excelRefund(param: object, callBack) {
    this.http.get(environment.orderUrl + 'excelRefund?'+this.common.getWhereCondition(param)).subscribe(data => {
      callBack(data);
    });
  }

}
