import { Injectable } from '@angular/core';
import {environment} from '../../environments/environment';
import {HttpClient} from '../../../node_modules/@angular/common/http';
import {CommonsService} from './commons.service';

@Injectable({
  providedIn: 'root'
})
export class CmsService {

  constructor(
    private http: HttpClient,
    private commonsService: CommonsService
  ) { }

    /**
     * 获取cms内容
     * @param paramObject  内容
     * @param callBack 回调
     */
    getListContent(paramObject: object, callBack) {
        this.http.get(environment.baseUrl + 'cmsContent/getListContent?' + this.commonsService.getWhereCondition(paramObject)).subscribe(data => {
            callBack(data);
        });
    }


  /**
   * 获取cms内容
   * @param paramObject  内容
   * @param callBack 回调
   */
  getListCmsContent(paramObject: object, callBack) {
    this.http.get(environment.baseUrl + 'cmsContent/getListCmsContent?' + this.commonsService.getWhereCondition(paramObject)).subscribe(data => {
      callBack(data);
    });
  }

    /**
     * 根据id查询详情
     *
     * @param  roleType   公司id
     * @param  callBack   回调
     */
    public getOwnCategoryTree(roleType: number, callBack) {
        this.http.get(environment.baseUrl + 'cmsCategory/getOwnCategoryTree?roleType=' + roleType).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * @Author Sum1Dream
     * @methodName getCategoryTree
     * @Description // 获取分类树数据
     * @Date 16:37 2023/2/1
     * @Param callBack
     */
    public getCategoryTree( callBack) {
        this.http.get(environment.baseUrl + '/cmsCategory/getCategoryTree').subscribe(data => {
            callBack(data);
        });
    }

    /**
     * 新增cms内容
     *
     * @param params 上传对象
     * @param  callBack   回调
     * @return data 返回结果
     */
    public insertCmsContent(params: object, callBack) {
        this.http.post(environment.baseUrl + 'cmsContent/insertCmsContent', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * 修改cms内容
     *
     * @param params 上传对象
     * @param  callBack   回调
     * @return data 返回结果
     */
    public updateCmsContent(params: object, callBack) {
        this.http.post(environment.baseUrl + 'cmsContent/updateCmsContent', params).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * 根据id查询详情
     *
     * @param  id   id
     * @param  callBack   回调
     */
    public findById(id: number, callBack) {
        this.http.get(environment.baseUrl + 'cmsContent/findById?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * 根据id删除内容
     *
     * @param  id   id
     * @param  callBack   回调
     */
    public deleteById(id: number, callBack) {
        this.http.get(environment.baseUrl + 'cmsContent/deleteById?id=' + id).subscribe(data => {
            callBack(data);
        });
    }

    /**
     * 修改公司状态
     *
     * @param id  用户id
     * @param status  status
     * @param callBack 返回参数
     */
    public updateContentStatus(id: number, status: number, callBack) {
        this.http.get(environment.baseUrl + 'cmsContent/updateContentStatus?id=' + id + '&status=' + status ).subscribe(data => {
            callBack(data);
        });
    }

}
